==> zio-aws-lambda_3-5.17.104.8-sources.jar: zio/aws/lambda/model/PutProvisionedConcurrencyConfigResponse.scala <==
package zio.aws.lambda.model
import java.lang.Integer
import zio.aws.lambda.model.primitives.{
  Timestamp,
  NonNegativeInteger,
  PositiveInteger
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class PutProvisionedConcurrencyConfigResponse(
    requestedProvisionedConcurrentExecutions: Option[PositiveInteger] = None,
    availableProvisionedConcurrentExecutions: Option[NonNegativeInteger] = None,
    allocatedProvisionedConcurrentExecutions: Option[NonNegativeInteger] = None,
    status: Option[zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum] =
      None,
    statusReason: Option[String] = None,
    lastModified: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse = {
    import PutProvisionedConcurrencyConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse
      .builder()
      .optionallyWith(
        requestedProvisionedConcurrentExecutions.map(value =>
          PositiveInteger.unwrap(value): Integer
        )
      )(_.requestedProvisionedConcurrentExecutions)
      .optionallyWith(
        availableProvisionedConcurrentExecutions.map(value =>
          NonNegativeInteger.unwrap(value): Integer
        )
      )(_.availableProvisionedConcurrentExecutions)
      .optionallyWith(
        allocatedProvisionedConcurrentExecutions.map(value =>
          NonNegativeInteger.unwrap(value): Integer
        )
      )(_.allocatedProvisionedConcurrentExecutions)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(statusReason.map(value => value: java.lang.String))(
        _.statusReason
      )
      .optionallyWith(
        lastModified.map(value => Timestamp.unwrap(value): java.lang.String)
      )(_.lastModified)
      .build()
  }
  def asReadOnly
      : zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse.ReadOnly =
    zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse
      .wrap(buildAwsValue())
}
object PutProvisionedConcurrencyConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse =
      zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse(
        requestedProvisionedConcurrentExecutions.map(value => value),
        availableProvisionedConcurrentExecutions.map(value => value),
        allocatedProvisionedConcurrentExecutions.map(value => value),
        status.map(value => value),
        statusReason.map(value => value),
        lastModified.map(value => value)
      )
    def requestedProvisionedConcurrentExecutions: Option[PositiveInteger]
    def availableProvisionedConcurrentExecutions: Option[NonNegativeInteger]
    def allocatedProvisionedConcurrentExecutions: Option[NonNegativeInteger]
    def status: Option[zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum]
    def statusReason: Option[String]
    def lastModified: Option[Timestamp]
    def getRequestedProvisionedConcurrentExecutions
        : ZIO[Any, AwsError, PositiveInteger] = AwsError.unwrapOptionField(
      "requestedProvisionedConcurrentExecutions",
      requestedProvisionedConcurrentExecutions
    )
    def getAvailableProvisionedConcurrentExecutions
        : ZIO[Any, AwsError, NonNegativeInteger] = AwsError.unwrapOptionField(
      "availableProvisionedConcurrentExecutions",
      availableProvisionedConcurrentExecutions
    )
    def getAllocatedProvisionedConcurrentExecutions
        : ZIO[Any, AwsError, NonNegativeInteger] = AwsError.unwrapOptionField(
      "allocatedProvisionedConcurrentExecutions",
      allocatedProvisionedConcurrentExecutions
    )
    def getStatus: ZIO[
      Any,
      AwsError,
      zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum
    ] = AwsError.unwrapOptionField("status", status)
    def getStatusReason: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("statusReason", statusReason)
    def getLastModified: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastModified", lastModified)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse
  ) extends zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse.ReadOnly {
    override val requestedProvisionedConcurrentExecutions
        : Option[PositiveInteger] = scala
      .Option(impl.requestedProvisionedConcurrentExecutions())
      .map(value => zio.aws.lambda.model.primitives.PositiveInteger(value))
    override val availableProvisionedConcurrentExecutions
        : Option[NonNegativeInteger] = scala
      .Option(impl.availableProvisionedConcurrentExecutions())
      .map(value => zio.aws.lambda.model.primitives.NonNegativeInteger(value))
    override val allocatedProvisionedConcurrentExecutions
        : Option[NonNegativeInteger] = scala
      .Option(impl.allocatedProvisionedConcurrentExecutions())
      .map(value => zio.aws.lambda.model.primitives.NonNegativeInteger(value))
    override val status
        : Option[zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum] = scala
      .Option(impl.status())
      .map(value =>
        zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum.wrap(value)
      )
    override val statusReason: Option[String] =
      scala.Option(impl.statusReason()).map(value => value: String)
    override val lastModified: Option[Timestamp] = scala
      .Option(impl.lastModified())
      .map(value => zio.aws.lambda.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse
  ): zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lambda_3-5.17.171.1-sources.jar: zio/aws/lambda/model/PutProvisionedConcurrencyConfigResponse.scala <==
package zio.aws.lambda.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lambda.model.primitives.{
  Timestamp,
  NonNegativeInteger,
  PositiveInteger
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class PutProvisionedConcurrencyConfigResponse(
    requestedProvisionedConcurrentExecutions: Optional[PositiveInteger] =
      Optional.Absent,
    availableProvisionedConcurrentExecutions: Optional[NonNegativeInteger] =
      Optional.Absent,
    allocatedProvisionedConcurrentExecutions: Optional[NonNegativeInteger] =
      Optional.Absent,
    status: Optional[zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum] =
      Optional.Absent,
    statusReason: Optional[String] = Optional.Absent,
    lastModified: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse = {
    import PutProvisionedConcurrencyConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse
      .builder()
      .optionallyWith(
        requestedProvisionedConcurrentExecutions.map(value =>
          PositiveInteger.unwrap(value): Integer
        )
      )(_.requestedProvisionedConcurrentExecutions)
      .optionallyWith(
        availableProvisionedConcurrentExecutions.map(value =>
          NonNegativeInteger.unwrap(value): Integer
        )
      )(_.availableProvisionedConcurrentExecutions)
      .optionallyWith(
        allocatedProvisionedConcurrentExecutions.map(value =>
          NonNegativeInteger.unwrap(value): Integer
        )
      )(_.allocatedProvisionedConcurrentExecutions)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(statusReason.map(value => value: java.lang.String))(
        _.statusReason
      )
      .optionallyWith(
        lastModified.map(value => Timestamp.unwrap(value): java.lang.String)
      )(_.lastModified)
      .build()
  }
  def asReadOnly
      : zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse.ReadOnly =
    zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse
      .wrap(buildAwsValue())
}
object PutProvisionedConcurrencyConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse =
      zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse(
        requestedProvisionedConcurrentExecutions.map(value => value),
        availableProvisionedConcurrentExecutions.map(value => value),
        allocatedProvisionedConcurrentExecutions.map(value => value),
        status.map(value => value),
        statusReason.map(value => value),
        lastModified.map(value => value)
      )
    def requestedProvisionedConcurrentExecutions: Optional[PositiveInteger]
    def availableProvisionedConcurrentExecutions: Optional[NonNegativeInteger]
    def allocatedProvisionedConcurrentExecutions: Optional[NonNegativeInteger]
    def status: Optional[zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum]
    def statusReason: Optional[String]
    def lastModified: Optional[Timestamp]
    def getRequestedProvisionedConcurrentExecutions
        : ZIO[Any, AwsError, PositiveInteger] = AwsError.unwrapOptionField(
      "requestedProvisionedConcurrentExecutions",
      requestedProvisionedConcurrentExecutions
    )
    def getAvailableProvisionedConcurrentExecutions
        : ZIO[Any, AwsError, NonNegativeInteger] = AwsError.unwrapOptionField(
      "availableProvisionedConcurrentExecutions",
      availableProvisionedConcurrentExecutions
    )
    def getAllocatedProvisionedConcurrentExecutions
        : ZIO[Any, AwsError, NonNegativeInteger] = AwsError.unwrapOptionField(
      "allocatedProvisionedConcurrentExecutions",
      allocatedProvisionedConcurrentExecutions
    )
    def getStatus: ZIO[
      Any,
      AwsError,
      zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum
    ] = AwsError.unwrapOptionField("status", status)
    def getStatusReason: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("statusReason", statusReason)
    def getLastModified: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastModified", lastModified)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse
  ) extends zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse.ReadOnly {
    override val requestedProvisionedConcurrentExecutions
        : Optional[PositiveInteger] = zio.aws.core.internal
      .optionalFromNullable(impl.requestedProvisionedConcurrentExecutions())
      .map(value => zio.aws.lambda.model.primitives.PositiveInteger(value))
    override val availableProvisionedConcurrentExecutions
        : Optional[NonNegativeInteger] = zio.aws.core.internal
      .optionalFromNullable(impl.availableProvisionedConcurrentExecutions())
      .map(value => zio.aws.lambda.model.primitives.NonNegativeInteger(value))
    override val allocatedProvisionedConcurrentExecutions
        : Optional[NonNegativeInteger] = zio.aws.core.internal
      .optionalFromNullable(impl.allocatedProvisionedConcurrentExecutions())
      .map(value => zio.aws.lambda.model.primitives.NonNegativeInteger(value))
    override val status
        : Optional[zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value =>
          zio.aws.lambda.model.ProvisionedConcurrencyStatusEnum.wrap(value)
        )
    override val statusReason: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.statusReason())
      .map(value => value: String)
    override val lastModified: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.lastModified())
      .map(value => zio.aws.lambda.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.PutProvisionedConcurrencyConfigResponse
  ): zio.aws.lambda.model.PutProvisionedConcurrencyConfigResponse.ReadOnly =
    new Wrapper(impl)
}
